I've also removed 'gksu' and 'sudo' from Depends, because it isn't needed. I added 'menu' because of 'su-to-root' command.

I hope now it's fine for upload =)

Thanks

--
Marco Rodrigues

http://Marco.Tondela.org
diff -Nru sbackup-0.10.4/debian/changelog sbackup-0.10.4.1/debian/changelog
--- sbackup-0.10.4/debian/changelog     2007-06-03 14:24:15.000000000 +0100
+++ sbackup-0.10.4.1/debian/changelog   2008-06-12 22:57:55.000000000 +0100
@@ -1,9 +1,19 @@
+sbackup (0.10.4.1) unstable; urgency=low
+
+  * Non-maintainer upload.
+  * Change 'admin' group to 'backup' one (Closes: #427697).
+  * Add 'su-to-root -X' to desktop files (Closes: #479826).
+  * Add 'menu' to Depends and removed 'gksu' and 'sudo'.
+  * Remove 'Encoding=UTF-8' from desktop files.
+
+ -- Marco Rodrigues <[EMAIL PROTECTED]>  Thu, 12 Jun 2008 22:39:42 +0100
+
 sbackup (0.10.4) unstable; urgency=low
 
   * Official release.
   * fix a bug preventing simple-backup-config to resolve anacron monthly
   * Ubuntu Bug #67814 - fixed permission problems with remote backups
-  
+
   * gksu is used instead of gksudo (Closes: #327222)
   * Cron job is removed on package purge (Closes: #346097)
   * Should not crash on non-dirs in backup target (Closes: #391948)
@@ -16,16 +26,16 @@
 sbackup (0.10.4~beta10) unstable; urgency=low
 
   * Public beta release
-  
+
  -- Aigars Mahinovs <[EMAIL PROTECTED]>  Sat, 19 May 2007 16:53:10 +0100
 
 sbackup (0.10.4~beta9) unstable; urgency=low
 
   * Gnomevfs doesn't close directory handler.
   * Hope this is the last beta
-  * Resolved a bug when using ssh 
+  * Resolved a bug when using ssh
   * change some errors printing
-  * admin GID is now get dynamically . 
+  * admin GID is now get dynamically .
   * Changed the right on the flist file to set read access to admin
   * Fixes a problem with incremental backups
   * Avoid usage of current dir for the lock file
@@ -74,12 +84,12 @@
 
 sbackup (0.10.2) unstable; urgency=high
 
-  * "Simple fixes for simple but annoying bugs" release - intended to go 
+  * "Simple fixes for simple but annoying bugs" release - intended to go
     into Etch and Edgy.
   * Manage /etc/sbackup.conf and /etc/cron.d/sbackup as config files, but
     not as conffiles, to remove unneeded "config changes upstream" prompt
     on upgrade. SBackup can handle old config gracefuly.
-  * Brown paperbag one-liner fix on incremental backup time not being counted 
+  * Brown paperbag one-liner fix on incremental backup time not being counted
     properly causing incremental backups to be done all the time.
   * Reduce nice level of sbackupd process to lowest possible priority (+19)
   * An empty regex matches everything, so avoid those
diff -Nru sbackup-0.10.4/debian/control sbackup-0.10.4.1/debian/control
--- sbackup-0.10.4/debian/control       2006-10-06 17:44:18.000000000 +0100
+++ sbackup-0.10.4.1/debian/control     2008-06-12 22:56:38.000000000 +0100
@@ -7,7 +7,7 @@
 
 Package: sbackup
 Architecture: all
-Depends: python, python-gnome2, python-glade2, gksu, sudo
+Depends: python, python-gnome2, python-glade2, menu
 Description: Simple Backup Suite for desktop use
  Simple Backup Suite is a set of backend backup daemon and Gnome
  GUI frontends that provide a simple yet powerful backup
diff -Nru sbackup-0.10.4/debian/menu sbackup-0.10.4.1/debian/menu
--- sbackup-0.10.4/debian/menu  2007-01-25 03:57:48.000000000 +0000
+++ sbackup-0.10.4.1/debian/menu        2008-06-12 22:35:35.000000000 +0100
@@ -1,4 +1,4 @@
 ?package(sbackup):needs="X11" section="Apps/System"\
-  title="Simple Backup Config" command="gksu /usr/sbin/simple-backup-config"
+  title="Simple Backup Config" command="su-to-root -X 
/usr/sbin/simple-backup-config"
 ?package(sbackup):needs="X11" section="Apps/System"\
-  title="Simple Restore" command="gksu /usr/sbin/simple-restore-gnome"
+  title="Simple Restore" command="su-to-root -X /usr/sbin/simple-restore-gnome"
diff -Nru sbackup-0.10.4/sbackup.desktop sbackup-0.10.4.1/sbackup.desktop
--- sbackup-0.10.4/sbackup.desktop      2007-05-08 19:33:59.000000000 +0100
+++ sbackup-0.10.4.1/sbackup.desktop    2008-06-12 22:35:08.000000000 +0100
@@ -1,9 +1,8 @@
 [Desktop Entry]
 Version=1.0
-Encoding=UTF-8
 Name=Simple Backup Config
 Comment=Configuration tool for Simple Backups Suite
-Exec=gksu simple-backup-config
+Exec=su-to-root -X simple-backup-config
 Terminal=false
 Type=Application
 Categories=Application;System;Settings
diff -Nru sbackup-0.10.4/srestore.desktop sbackup-0.10.4.1/srestore.desktop
--- sbackup-0.10.4/srestore.desktop     2007-05-08 19:33:59.000000000 +0100
+++ sbackup-0.10.4.1/srestore.desktop   2008-06-12 22:45:31.000000000 +0100
@@ -1,9 +1,8 @@
 [Desktop Entry]
 Version=1.0
-Encoding=UTF-8
 Name=Simple Backup Restore
 Comment=Restore tool for Simple Backups Suite
-Exec=gksu simple-restore-gnome
+Exec=su-to-root -X simple-restore-gnome
 Terminal=false
 Type=Application
 Categories=Application;System;Settings

Reply via email to
diff -Nru sbackup-0.10.4/sbackupd.py sbackup-0.10.4.1/sbackupd.py
--- sbackup-0.10.4/sbackupd.py  2007-05-13 07:21:34.000000000 +0100
+++ sbackup-0.10.4.1/sbackupd.py        2008-06-12 22:38:07.000000000 +0100
@@ -177,12 +177,12 @@
 # Check our user id
 if os.geteuid() != 0: sys.exit (_("Currently backup is only runnable by root"))
 
-# [Bug 112540] : Let the admin group have read access to the backup dirs
+# [Bug 112540] : Let the backup group have read access to the backup dirs
 try :
-       # The uid is still root and the gid is admin
-       os.setgid( grp.getgrnam("admin").gr_gid )
+       # The uid is still root and the gid is backup
+       os.setgid( grp.getgrnam("backup").gr_gid )
 except Exception, e: 
-       print "W: Failed to set the gid to 'admin' one :" + str(e)
+       print "W: Failed to set the gid to 'backup' one :" + str(e)
        pass
 
 # second we read the config file, so must check if the user provided one on the